# -*- coding: utf-8 -*-

import pandas as pd
from pycaret.classification import load_model, predict_model
from fastapi import FastAPI
import uvicorn
from pydantic import create_model

# Create the app
app = FastAPI()

# Load trained Pipeline
model = load_model("api_ricco")

# Create input/output pydantic models
input_model = create_model("api_ricco_input", **{'diastolic': 70.0, 'bodymass': 35.29999923706055, 'age': 39.0, 'plasma': 74.0})
output_model = create_model("api_ricco_output", prediction='negative')


# Define predict function
@app.post("/predict", response_model=output_model)
def predict(data: input_model):
    data = pd.DataFrame([data.dict()])
    predictions = predict_model(model, data=data)
    return {"prediction": predictions["prediction_label"].iloc[0]}


if __name__ == "__main__":
    uvicorn.run(app, host="127.0.0.1", port=8000)
